@@ -3,6 +3,8 @@
 // Copyright 2012  Johns Hopkins University (author: Daniel Povey);
 //                 Haihua Xu; Wei Shi
 
+// Modified 2022 by Sean Robertson, listed.
+
 // See ../../COPYING for clarification regarding multiple authors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,135 +28,143 @@
 #include "matrix/kaldi-vector.h"
 #include "matrix/kaldi-matrix.h"
 #include "matrix/matrix-functions.h"
+#include "matrix/kaldi-blas.h"
 
 // Do not include this file directly.  It is to be included
 // by .cc files in this directory.
 
+#ifdef HAVE_NOBLAS
+  // sdrobert: will throw whenever any of these wrappers are called
+  #define IMP_CHECK(a) throw std::logic_error("not compiled with blas")
+#else
+  #define IMP_CHECK(a) a
+#endif
+
 namespace kaldi {
 
 
 inline void cblas_Xcopy(const int N, const float *X, const int incX, float *Y,
                         const int incY) {
-  cblas_scopy(N, X, incX, Y, incY);
+  IMP_CHECK(cblas_scopy(N, X, incX, Y, incY));
 }
 
 inline void cblas_Xcopy(const int N, const double *X, const int incX, double *Y,
                         const int incY) {
-  cblas_dcopy(N, X, incX, Y, incY);
+  IMP_CHECK(cblas_dcopy(N, X, incX, Y, incY));
 }
 
 
 inline float cblas_Xasum(const int N, const float *X, const int incX) {
-  return cblas_sasum(N, X, incX);
+  IMP_CHECK(return cblas_sasum(N, X, incX));
 }
 
 inline double cblas_Xasum(const int N, const double *X, const int incX) {
-  return cblas_dasum(N, X, incX);
+  IMP_CHECK(return cblas_dasum(N, X, incX));
 }
 
 inline void cblas_Xrot(const int N, float *X, const int incX, float *Y,
                        const int incY, const float c, const float s) {
-  cblas_srot(N, X, incX, Y, incY, c, s);
+  IMP_CHECK(cblas_srot(N, X, incX, Y, incY, c, s));
 }
 inline void cblas_Xrot(const int N, double *X, const int incX, double *Y,
                        const int incY, const double c, const double s) {
-  cblas_drot(N, X, incX, Y, incY, c, s);
+  IMP_CHECK(cblas_drot(N, X, incX, Y, incY, c, s));
 }
 inline float cblas_Xdot(const int N, const float *const X,
                         const int incX, const float *const Y,
                         const int incY) {
-  return cblas_sdot(N, X, incX, Y, incY);
+  IMP_CHECK(return cblas_sdot(N, X, incX, Y, incY));
 }
 inline double cblas_Xdot(const int N, const double *const X,
                         const int incX, const double *const Y,
                         const int incY) {
-  return cblas_ddot(N, X, incX, Y, incY);
+  IMP_CHECK(return cblas_ddot(N, X, incX, Y, incY));
 }
 inline void cblas_Xaxpy(const int N, const float alpha, const float *X,
                         const int incX, float *Y, const int incY) {
-  cblas_saxpy(N, alpha, X, incX, Y, incY);
+  IMP_CHECK(cblas_saxpy(N, alpha, X, incX, Y, incY));
 }
 inline void cblas_Xaxpy(const int N, const double alpha, const double *X,
                         const int incX, double *Y, const int incY) {
-  cblas_daxpy(N, alpha, X, incX, Y, incY);
+  IMP_CHECK(cblas_daxpy(N, alpha, X, incX, Y, incY));
 }
 inline void cblas_Xscal(const int N, const float alpha, float *data,
                         const int inc) {
-  cblas_sscal(N, alpha, data, inc);
+  IMP_CHECK(cblas_sscal(N, alpha, data, inc));
 }
 inline void cblas_Xscal(const int N, const double alpha, double *data, 
                         const int inc) {
-  cblas_dscal(N, alpha, data, inc);
+  IMP_CHECK(cblas_dscal(N, alpha, data, inc));
 }
 inline void cblas_Xspmv(const float alpha, const int num_rows, const float *Mdata,
                         const float *v, const int v_inc,
                         const float beta, float *y, const int y_inc) {
-  cblas_sspmv(CblasRowMajor, CblasLower, num_rows, alpha, Mdata, v, v_inc, beta, y, y_inc);
+  IMP_CHECK(cblas_sspmv(CblasRowMajor, CblasLower, num_rows, alpha, Mdata, v, v_inc, beta, y, y_inc));
 }
 inline void cblas_Xspmv(const double alpha, const int num_rows, const double *Mdata,
                         const double *v, const int v_inc,
                         const double beta, double *y, const int y_inc) {
-  cblas_dspmv(CblasRowMajor, CblasLower, num_rows, alpha, Mdata, v, v_inc, beta, y, y_inc);
+  IMP_CHECK(cblas_dspmv(CblasRowMajor, CblasLower, num_rows, alpha, Mdata, v, v_inc, beta, y, y_inc));
 }
 inline void cblas_Xtpmv(MatrixTransposeType trans, const float *Mdata,
                         const int num_rows, float *y, const int y_inc) {
-  cblas_stpmv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              CblasNonUnit, num_rows, Mdata, y, y_inc);
+  IMP_CHECK(cblas_stpmv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              CblasNonUnit, num_rows, Mdata, y, y_inc));
 }
 inline void cblas_Xtpmv(MatrixTransposeType trans, const double *Mdata,
                         const int num_rows, double *y, const int y_inc) {
-  cblas_dtpmv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              CblasNonUnit, num_rows, Mdata, y, y_inc);
+  IMP_CHECK(cblas_dtpmv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              CblasNonUnit, num_rows, Mdata, y, y_inc));
 }
 
 
 inline void cblas_Xtpsv(MatrixTransposeType trans, const float *Mdata,
                         const int num_rows, float *y, const int y_inc) {
-  cblas_stpsv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              CblasNonUnit, num_rows, Mdata, y, y_inc);
+  IMP_CHECK(cblas_stpsv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              CblasNonUnit, num_rows, Mdata, y, y_inc));
 }
 inline void cblas_Xtpsv(MatrixTransposeType trans, const double *Mdata,
                         const int num_rows, double *y, const int y_inc) {
-  cblas_dtpsv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              CblasNonUnit, num_rows, Mdata, y, y_inc);
+  IMP_CHECK(cblas_dtpsv(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              CblasNonUnit, num_rows, Mdata, y, y_inc));
 }
 
 // x = alpha * M * y + beta * x
 inline void cblas_Xspmv(MatrixIndexT dim, float alpha, const float *Mdata,
                         const float *ydata, MatrixIndexT ystride,
                         float beta, float *xdata, MatrixIndexT xstride) {
-  cblas_sspmv(CblasRowMajor, CblasLower, dim, alpha, Mdata,
-              ydata, ystride, beta, xdata, xstride);
+  IMP_CHECK(cblas_sspmv(CblasRowMajor, CblasLower, dim, alpha, Mdata,
+              ydata, ystride, beta, xdata, xstride));
 }
 inline void cblas_Xspmv(MatrixIndexT dim, double alpha, const double *Mdata,
                         const double *ydata, MatrixIndexT ystride,
                         double beta, double *xdata, MatrixIndexT xstride) {
-  cblas_dspmv(CblasRowMajor, CblasLower, dim, alpha, Mdata,
-              ydata, ystride, beta, xdata, xstride);
+  IMP_CHECK(cblas_dspmv(CblasRowMajor, CblasLower, dim, alpha, Mdata,
+              ydata, ystride, beta, xdata, xstride));
 }
 
 // Implements  A += alpha * (x y'  + y x'); A is symmetric matrix.
 inline void cblas_Xspr2(MatrixIndexT dim, float alpha, const float *Xdata,
                         MatrixIndexT incX, const float *Ydata, MatrixIndexT incY,
                           float *Adata) {
-  cblas_sspr2(CblasRowMajor, CblasLower, dim, alpha, Xdata,
-              incX, Ydata, incY, Adata);
+  IMP_CHECK(cblas_sspr2(CblasRowMajor, CblasLower, dim, alpha, Xdata,
+              incX, Ydata, incY, Adata));
 }
 inline void cblas_Xspr2(MatrixIndexT dim, double alpha, const double *Xdata,
                         MatrixIndexT incX, const double *Ydata, MatrixIndexT incY,
                         double *Adata) {
-  cblas_dspr2(CblasRowMajor, CblasLower, dim, alpha, Xdata,
-              incX, Ydata, incY, Adata);
+  IMP_CHECK(cblas_dspr2(CblasRowMajor, CblasLower, dim, alpha, Xdata,
+              incX, Ydata, incY, Adata));
 }
 
 // Implements  A += alpha * (x x'); A is symmetric matrix.
 inline void cblas_Xspr(MatrixIndexT dim, float alpha, const float *Xdata,
                        MatrixIndexT incX, float *Adata) {
-  cblas_sspr(CblasRowMajor, CblasLower, dim, alpha, Xdata, incX, Adata);
+  IMP_CHECK(cblas_sspr(CblasRowMajor, CblasLower, dim, alpha, Xdata, incX, Adata));
 }
 inline void cblas_Xspr(MatrixIndexT dim, double alpha, const double *Xdata,
                        MatrixIndexT incX, double *Adata) {
-  cblas_dspr(CblasRowMajor, CblasLower, dim, alpha, Xdata, incX, Adata);
+  IMP_CHECK(cblas_dspr(CblasRowMajor, CblasLower, dim, alpha, Xdata, incX, Adata));
 }
 
 // sgemv,dgemv: y = alpha M x + beta y.
@@ -162,15 +172,15 @@ inline void cblas_Xgemv(MatrixTransposeType trans, MatrixIndexT num_rows,
                         MatrixIndexT num_cols, float alpha, const float *Mdata,
                         MatrixIndexT stride, const float *xdata,
                         MatrixIndexT incX, float beta, float *ydata, MatrixIndexT incY) {
-  cblas_sgemv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
-              num_cols, alpha, Mdata, stride, xdata, incX, beta, ydata, incY);
+  IMP_CHECK(cblas_sgemv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
+              num_cols, alpha, Mdata, stride, xdata, incX, beta, ydata, incY));
 }
 inline void cblas_Xgemv(MatrixTransposeType trans, MatrixIndexT num_rows,
                         MatrixIndexT num_cols, double alpha, const double *Mdata,
                         MatrixIndexT stride, const double *xdata,
                         MatrixIndexT incX, double beta, double *ydata, MatrixIndexT incY) {
-  cblas_dgemv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
-              num_cols, alpha, Mdata, stride, xdata, incX, beta, ydata, incY);
+  IMP_CHECK(cblas_dgemv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
+              num_cols, alpha, Mdata, stride, xdata, incX, beta, ydata, incY));
 }
 
 // sgbmv, dgmmv: y = alpha M x +  + beta * y.
@@ -179,18 +189,18 @@ inline void cblas_Xgbmv(MatrixTransposeType trans, MatrixIndexT num_rows,
                         MatrixIndexT num_above, float alpha, const float *Mdata,
                         MatrixIndexT stride, const float *xdata,
                         MatrixIndexT incX, float beta, float *ydata, MatrixIndexT incY) {
-  cblas_sgbmv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
+  IMP_CHECK(cblas_sgbmv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
               num_cols, num_below, num_above, alpha, Mdata, stride, xdata,
-              incX, beta, ydata, incY);
+              incX, beta, ydata, incY));
 }
 inline void cblas_Xgbmv(MatrixTransposeType trans, MatrixIndexT num_rows,
                         MatrixIndexT num_cols, MatrixIndexT num_below,
                         MatrixIndexT num_above, double alpha, const double *Mdata,
                         MatrixIndexT stride, const double *xdata,
                         MatrixIndexT incX, double beta, double *ydata, MatrixIndexT incY) {
-  cblas_dgbmv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
+  IMP_CHECK(cblas_dgbmv(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(trans), num_rows,
               num_cols, num_below, num_above, alpha, Mdata, stride, xdata,
-              incX, beta, ydata, incY);
+              incX, beta, ydata, incY));
 }
 
 
@@ -229,11 +239,11 @@ inline void cblas_Xgemm(const float alpha,
                         const float beta,
                         float *Mdata, 
                         MatrixIndexT num_rows, MatrixIndexT num_cols,MatrixIndexT stride) {
-  cblas_sgemm(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(transA), 
+  IMP_CHECK(cblas_sgemm(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(transA), 
               static_cast<CBLAS_TRANSPOSE>(transB),
               num_rows, num_cols, transA == kNoTrans ? a_num_cols : a_num_rows,
               alpha, Adata, a_stride, Bdata, b_stride,
-              beta, Mdata, stride); 
+              beta, Mdata, stride)); 
 }
 inline void cblas_Xgemm(const double alpha,
                         MatrixTransposeType transA,
@@ -244,11 +254,11 @@ inline void cblas_Xgemm(const double alpha,
                         const double beta,
                         double *Mdata, 
                         MatrixIndexT num_rows, MatrixIndexT num_cols,MatrixIndexT stride) {
-  cblas_dgemm(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(transA), 
+  IMP_CHECK(cblas_dgemm(CblasRowMajor, static_cast<CBLAS_TRANSPOSE>(transA), 
               static_cast<CBLAS_TRANSPOSE>(transB),
               num_rows, num_cols, transA == kNoTrans ? a_num_cols : a_num_rows,
               alpha, Adata, a_stride, Bdata, b_stride,
-              beta, Mdata, stride); 
+              beta, Mdata, stride)); 
 }
 
 
@@ -258,8 +268,8 @@ inline void cblas_Xsymm(const float alpha,
                         const float *Bdata,MatrixIndexT b_stride,
                         const float beta,
                         float *Mdata, MatrixIndexT stride) {
-  cblas_ssymm(CblasRowMajor, CblasLeft, CblasLower, sz, sz, alpha, Adata,
-              a_stride, Bdata, b_stride, beta, Mdata, stride);
+  IMP_CHECK(cblas_ssymm(CblasRowMajor, CblasLeft, CblasLower, sz, sz, alpha, Adata,
+              a_stride, Bdata, b_stride, beta, Mdata, stride));
 }
 inline void cblas_Xsymm(const double alpha,
                         MatrixIndexT sz,
@@ -267,21 +277,21 @@ inline void cblas_Xsymm(const double alpha,
                         const double *Bdata,MatrixIndexT b_stride,
                         const double beta,
                         double *Mdata, MatrixIndexT stride) {
-  cblas_dsymm(CblasRowMajor, CblasLeft, CblasLower, sz, sz, alpha, Adata,
-              a_stride, Bdata, b_stride, beta, Mdata, stride);
+  IMP_CHECK(cblas_dsymm(CblasRowMajor, CblasLeft, CblasLower, sz, sz, alpha, Adata,
+              a_stride, Bdata, b_stride, beta, Mdata, stride));
 }
 // ger: M += alpha x y^T.
 inline void cblas_Xger(MatrixIndexT num_rows, MatrixIndexT num_cols, float alpha,
                        const float *xdata, MatrixIndexT incX, const float *ydata,
                        MatrixIndexT incY, float *Mdata, MatrixIndexT stride) {
-  cblas_sger(CblasRowMajor, num_rows, num_cols, alpha, xdata, 1, ydata, 1,
-             Mdata, stride);
+  IMP_CHECK(cblas_sger(CblasRowMajor, num_rows, num_cols, alpha, xdata, 1, ydata, 1,
+             Mdata, stride));
 }
 inline void cblas_Xger(MatrixIndexT num_rows, MatrixIndexT num_cols, double alpha,
                        const double *xdata, MatrixIndexT incX, const double *ydata,
                        MatrixIndexT incY, double *Mdata, MatrixIndexT stride) {
-  cblas_dger(CblasRowMajor, num_rows, num_cols, alpha, xdata, 1, ydata, 1,
-             Mdata, stride);
+  IMP_CHECK(cblas_dger(CblasRowMajor, num_rows, num_cols, alpha, xdata, 1, ydata, 1,
+             Mdata, stride));
 }
 
 // syrk: symmetric rank-k update.
@@ -296,8 +306,8 @@ inline void cblas_Xsyrk (
     const MatrixIndexT other_dim_a, const float alpha, const float *A,
     const MatrixIndexT a_stride, const float beta, float *C,
     const MatrixIndexT c_stride) {
-  cblas_ssyrk(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              dim_c, other_dim_a, alpha, A, a_stride, beta, C, c_stride);
+  IMP_CHECK(cblas_ssyrk(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              dim_c, other_dim_a, alpha, A, a_stride, beta, C, c_stride));
 }
 
 inline void cblas_Xsyrk(
@@ -305,8 +315,8 @@ inline void cblas_Xsyrk(
     const MatrixIndexT other_dim_a, const double alpha, const double *A,
     const MatrixIndexT a_stride, const double beta, double *C,
     const MatrixIndexT c_stride) {
-  cblas_dsyrk(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
-              dim_c, other_dim_a, alpha, A, a_stride, beta, C, c_stride);
+  IMP_CHECK(cblas_dsyrk(CblasRowMajor, CblasLower, static_cast<CBLAS_TRANSPOSE>(trans),
+              dim_c, other_dim_a, alpha, A, a_stride, beta, C, c_stride));
 }
 
 /// matrix-vector multiply using a banded matrix; we always call this
@@ -320,8 +330,8 @@ inline void cblas_Xsbmv1(
     const double *x,
     const double beta,
     double *y) {
-  cblas_dsbmv(CblasRowMajor, CblasLower, dim, 0, alpha, A,
-              1, x, 1, beta, y, 1);
+  IMP_CHECK(cblas_dsbmv(CblasRowMajor, CblasLower, dim, 0, alpha, A,
+              1, x, 1, beta, y, 1));
 }
 
 inline void cblas_Xsbmv1(
@@ -331,11 +341,10 @@ inline void cblas_Xsbmv1(
     const float *x,
     const float beta,
     float *y) {
-  cblas_ssbmv(CblasRowMajor, CblasLower, dim, 0, alpha, A,
-              1, x, 1, beta, y, 1);
+  IMP_CHECK(cblas_ssbmv(CblasRowMajor, CblasLower, dim, 0, alpha, A,
+              1, x, 1, beta, y, 1));
 }
 
-
 /// This is not really a wrapper for CBLAS as CBLAS does not have this; in future we could
 /// extend this somehow.
 inline void mul_elements(
@@ -383,33 +392,33 @@ inline void mul_elements(
 // add clapack here
 #if !defined(HAVE_ATLAS)
 inline void clapack_Xtptri(KaldiBlasInt *num_rows, float *Mdata, KaldiBlasInt *result) {
-  stptri_(const_cast<char *>("U"), const_cast<char *>("N"), num_rows, Mdata, result);
+  IMP_CHECK(stptri_(const_cast<char *>("U"), const_cast<char *>("N"), num_rows, Mdata, result));
 }
 inline void clapack_Xtptri(KaldiBlasInt *num_rows, double *Mdata, KaldiBlasInt *result) {
-  dtptri_(const_cast<char *>("U"), const_cast<char *>("N"), num_rows, Mdata, result);
+  IMP_CHECK(dtptri_(const_cast<char *>("U"), const_cast<char *>("N"), num_rows, Mdata, result));
 }
 // 
 inline void clapack_Xgetrf2(KaldiBlasInt *num_rows, KaldiBlasInt *num_cols, 
                             float *Mdata, KaldiBlasInt *stride, KaldiBlasInt *pivot, 
                             KaldiBlasInt *result) {
-  sgetrf_(num_rows, num_cols, Mdata, stride, pivot, result);
+  IMP_CHECK(sgetrf_(num_rows, num_cols, Mdata, stride, pivot, result));
 }
 inline void clapack_Xgetrf2(KaldiBlasInt *num_rows, KaldiBlasInt *num_cols, 
                             double *Mdata, KaldiBlasInt *stride, KaldiBlasInt *pivot, 
                             KaldiBlasInt *result) {
-  dgetrf_(num_rows, num_cols, Mdata, stride, pivot, result);
+  IMP_CHECK(dgetrf_(num_rows, num_cols, Mdata, stride, pivot, result));
 }
 
 // 
 inline void clapack_Xgetri2(KaldiBlasInt *num_rows, float *Mdata, KaldiBlasInt *stride,
                            KaldiBlasInt *pivot, float *p_work, 
                            KaldiBlasInt *l_work, KaldiBlasInt *result) {
-  sgetri_(num_rows, Mdata, stride, pivot, p_work, l_work, result);
+  IMP_CHECK(sgetri_(num_rows, Mdata, stride, pivot, p_work, l_work, result));
 }
 inline void clapack_Xgetri2(KaldiBlasInt *num_rows, double *Mdata, KaldiBlasInt *stride,
                            KaldiBlasInt *pivot, double *p_work, 
                            KaldiBlasInt *l_work, KaldiBlasInt *result) {
-  dgetri_(num_rows, Mdata, stride, pivot, p_work, l_work, result);
+  IMP_CHECK(dgetri_(num_rows, Mdata, stride, pivot, p_work, l_work, result));
 }
 //
 inline void clapack_Xgesvd(char *v, char *u, KaldiBlasInt *num_cols,
@@ -417,40 +426,41 @@ inline void clapack_Xgesvd(char *v, char *u, KaldiBlasInt *num_cols,
                            float *sv, float *Vdata, KaldiBlasInt *vstride,
                            float *Udata, KaldiBlasInt *ustride, float *p_work,
                            KaldiBlasInt *l_work, KaldiBlasInt *result) {
-  sgesvd_(v, u,
+  IMP_CHECK(sgesvd_(v, u,
           num_cols, num_rows, Mdata, stride,
           sv, Vdata, vstride, Udata, ustride, 
-          p_work, l_work, result); 
+          p_work, l_work, result)); 
 }
 inline void clapack_Xgesvd(char *v, char *u, KaldiBlasInt *num_cols,
                            KaldiBlasInt *num_rows, double *Mdata, KaldiBlasInt *stride,
                            double *sv, double *Vdata, KaldiBlasInt *vstride,
                            double *Udata, KaldiBlasInt *ustride, double *p_work,
                            KaldiBlasInt *l_work, KaldiBlasInt *result) {
-  dgesvd_(v, u,
+  IMP_CHECK(dgesvd_(v, u,
           num_cols, num_rows, Mdata, stride,
           sv, Vdata, vstride, Udata, ustride,
-          p_work, l_work, result); 
+          p_work, l_work, result)); 
 }
 //
 void inline clapack_Xsptri(KaldiBlasInt *num_rows, float *Mdata, 
                            KaldiBlasInt *ipiv, float *work, KaldiBlasInt *result) {
-  ssptri_(const_cast<char *>("U"), num_rows, Mdata, ipiv, work, result);
+  IMP_CHECK(ssptri_(const_cast<char *>("U"), num_rows, Mdata, ipiv, work, result));
 }
 void inline clapack_Xsptri(KaldiBlasInt *num_rows, double *Mdata, 
                            KaldiBlasInt *ipiv, double *work, KaldiBlasInt *result) {
-  dsptri_(const_cast<char *>("U"), num_rows, Mdata, ipiv, work, result);
+  IMP_CHECK(dsptri_(const_cast<char *>("U"), num_rows, Mdata, ipiv, work, result));
 }
 //
 void inline clapack_Xsptrf(KaldiBlasInt *num_rows, float *Mdata,
                            KaldiBlasInt *ipiv, KaldiBlasInt *result) {
-  ssptrf_(const_cast<char *>("U"), num_rows, Mdata, ipiv, result);
+  IMP_CHECK(ssptrf_(const_cast<char *>("U"), num_rows, Mdata, ipiv, result));
 }
 void inline clapack_Xsptrf(KaldiBlasInt *num_rows, double *Mdata,
                            KaldiBlasInt *ipiv, KaldiBlasInt *result) {
-  dsptrf_(const_cast<char *>("U"), num_rows, Mdata, ipiv, result);
+  IMP_CHECK(dsptrf_(const_cast<char *>("U"), num_rows, Mdata, ipiv, result));
 }
 #else
+// sdrobert: no need for IMP_CHECK - HAVE_ATLAS is true
 inline void clapack_Xgetrf(MatrixIndexT num_rows, MatrixIndexT num_cols,
                            float *Mdata, MatrixIndexT stride, 
                            int *pivot, int *result) {
